==> eiffelstudio-18.11.10.2592.tar: F_code/C20/me951.c <==
/*
 * Code for class MEMBER_FILTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "me951.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {MEMBER_FILTER}.make */
void F1060_14614 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("make", 1059, Current, 0, 0, 14185);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {2664,10,4075,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F2665_27054(RTCW(tr1), ((EIF_INTEGER_32) 10000L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	{
		static EIF_TYPE_INDEX typarr0[] = {2609,4075,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F2583_26673(RTCW(tr1), ((EIF_INTEGER_32) 10L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	tr1 = RTLNS(eif_new_type(1054, 0x00).id, 1054, _OBJSIZ_0_0_0_0_0_0_0_0_);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(4);
	tr1 = RTLNSMART(eif_new_type(7149, 0).id);
	F7149_98597(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) tr1;
	RTHOOK(5);
	tr1 = RTLNSMART(eif_new_type(10, 0).id);
	F11_143(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {MEMBER_FILTER}.xml_members */
EIF_REFERENCE F1060_14615 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_1_);
}


/* {MEMBER_FILTER}.set_offset */
void F1060_14617 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_offset", 1059, Current, 0, 1, 14188);
	RTHOOK(2);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_1_0_0_) = (EIF_INTEGER_32) arg1;
	RTHOOK(4);
	RTEE;
}

/* {MEMBER_FILTER}.current_xml_member */
EIF_REFERENCE F1060_14618 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_2_);
}


/* {MEMBER_FILTER}.current_tag */
EIF_REFERENCE F1060_14619 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_3_);
}


/* {MEMBER_FILTER}.on_start_tag */
void F1060_14621 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_INTEGER_32 ti4_3;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg3);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLR(5,arg2);
	RTLIU(6);
	
	RTEAA("on_start_tag", 1059, Current, 1, 3, 14192);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F2610_26800(RTCW(tr1), arg3);
	RTHOOK(2);
	tr1 = RTMS_EX_H("member",6,2050243442);
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R11[Dtype(arg3)-0])(RTCW(arg3), tr1);
	if (tb1) {
		RTHOOK(3);
		tr1 = RTLNSMART(eif_new_type(10, 0).id);
		F11_143(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
		RTHOOK(4);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_5_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		RTHOOK(5);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		loc1 = F7149_98617(RTCW(tr1));
		
		RTHOOK(7);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_1_0_0_);
		ti4_2 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_0_0_2_);
		ti4_3 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_0_0_1_);
		F11_148(RTCW(tr1), (EIF_INTEGER_32) ((EIF_INTEGER_32) (ti4_1 + ti4_2) - ti4_3));
	}
	RTHOOK(8);
	F1056_14575(Current, arg1, arg2, arg3);
	RTHOOK(9);
	RTLE;
	RTEE;
}

/* {MEMBER_FILTER}.on_attribute */
void F1060_14622 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(9);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,loc2);
	RTLR(4,arg4);
	RTLR(5,loc1);
	RTLR(6,arg1);
	RTLR(7,arg2);
	RTLR(8,arg3);
	RTLIU(9);
	
	RTEAA("on_attribute", 1059, Current, 2, 4, 14193);
	RTGC;
	RTHOOK(1);
	tb1 = '\0';
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_5_0_)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		tr1 = F2583_26678(RTCW(tr1));
		tr2 = RTMS_EX_H("member",6,2050243442);
		tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R11[Dtype(tr1)-0])(RTCW(tr1), tr2);
		tb1 = tb2;
	}
	if (tb1) {
		
		RTHOOK(3);
		loc2 = arg4;
		loc2 = RTRV(eif_new_type(4075, 0x00), loc2);
		RTHOOK(4);
		if ((EIF_BOOLEAN)(loc2 != NULL)) {
			RTHOOK(5);
			loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R37353[Dtype(loc2)-4073])(RTCW(loc2));
		} else {
			RTHOOK(6);
			loc1 = (EIF_REFERENCE) eif_builtin_ANY_twin (arg4);
		}
		RTHOOK(7);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1) + O37372[Dtype(loc1)-4073]);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R37227[Dtype(loc1)-4071])(RTCW(loc1), (EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 2L)));
		RTHOOK(8);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		F11_147(RTCW(tr1), loc1);
		RTHOOK(9);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_5_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	}
	RTHOOK(10);
	F1056_14576(Current, arg1, arg2, arg3, arg4);
	RTHOOK(11);
	RTLE;
	RTEE;
}

/* {MEMBER_FILTER}.on_end_tag */
void F1060_14623 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(7);
	RTLR(0,arg3);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,loc2);
	RTLR(4,tr2);
	RTLR(5,arg1);
	RTLR(6,arg2);
	RTLIU(7);
	
	RTEAA("on_end_tag", 1059, Current, 2, 3, 14194);
	RTGC;
	RTHOOK(1);
	tr1 = RTMS_EX_H("member",6,2050243442);
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R11[Dtype(arg3)-0])(RTCW(arg3), tr1);
	if (tb1) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_0_0_0_);
		if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 0L))) {
			RTHOOK(3);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			loc2 = F7149_98617(RTCW(tr1));
			
			RTHOOK(5);
			loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_1_0_0_);
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc2)+ _LNGOFF_1_0_0_2_);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
			ti4_2 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_0_0_0_);
			loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc1 + ti4_1) - ti4_2);
			RTHOOK(6);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
			F11_149(RTCW(tr1), loc1);
			RTHOOK(7);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			tr2 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
			tr2 = *(EIF_REFERENCE *)(RTCW(tr2));
			F2665_27100(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_2_), tr2);
		}
	}
	RTHOOK(8);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F2610_26803(RTCW(tr1));
	RTHOOK(9);
	F1056_14578(Current, arg1, arg2, arg3);
	RTHOOK(10);
	RTLE;
	RTEE;
}

/* {MEMBER_FILTER}.parser */
EIF_REFERENCE F1060_14624 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_4_);
}


/* {MEMBER_FILTER}.set_parser */
void F1060_14625 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_parser", 1059, Current, 0, 1, 14196);
	RTHOOK(2);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg1;
	RTHOOK(4);
	RTEE;
}

void EIF_Minit951 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C20/me951.c <==
/*
 * Code for class MEMBER_FILTER
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "me951.h"
#include "eif_built_in.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {MEMBER_FILTER}.make */
void F1056_16223 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTCFDT;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLIU(2);
	
	RTEAA("make", 1055, Current, 0, 0, 14117);
	RTGC;
	RTHOOK(1);
	{
		static EIF_TYPE_INDEX typarr0[] = {2722,29,4148,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F2723_30520(RTCW(tr1), ((EIF_INTEGER_32) 10000L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_1_) = (EIF_REFERENCE) tr1;
	RTHOOK(2);
	{
		static EIF_TYPE_INDEX typarr0[] = {2669,4148,0xFFFF};
		EIF_TYPE typres0;
		static EIF_TYPE typcache0 = {INVALID_DTYPE, 0};
		
		typres0 = (typcache0.id != INVALID_DTYPE ? typcache0 : (typcache0 = eif_compound_id(dftype, typarr0)));
		tr1 = RTLNSMART(typres0.id);
	}
	F2640_30068(RTCW(tr1), ((EIF_INTEGER_32) 10L));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_3_) = (EIF_REFERENCE) tr1;
	RTHOOK(3);
	tr1 = RTLNS(eif_new_type(1050, 0x00).id, 1050, _OBJSIZ_0_0_0_0_0_0_0_0_);
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current) = (EIF_REFERENCE) tr1;
	RTHOOK(4);
	tr1 = RTLNSMART(eif_new_type(7245, 0).id);
	F7245_105153(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) tr1;
	RTHOOK(5);
	tr1 = RTLNSMART(eif_new_type(29, 0).id);
	F30_1286(RTCW(tr1));
	RTAR(Current, tr1);
	*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
	RTHOOK(8);
	RTLE;
	RTEE;
}

/* {MEMBER_FILTER}.set_offset */
void F1056_16226 (EIF_REFERENCE Current, EIF_INTEGER_32 arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_offset", 1055, Current, 0, 1, 14120);
	RTHOOK(1);
	*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_1_0_0_) = (EIF_INTEGER_32) arg1;
	RTHOOK(3);
	RTEE;
}

/* {MEMBER_FILTER}.on_start_tag */
void F1056_16230 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(6);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,arg3);
	RTLR(3,loc1);
	RTLR(4,arg1);
	RTLR(5,arg2);
	RTLIU(6);
	
	RTEAA("on_start_tag", 1055, Current, 1, 3, 14124);
	RTGC;
	RTHOOK(1);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F2670_30248(RTCW(tr1), arg3);
	RTHOOK(2);
	tr1 = RTMS_EX_H("member",6,2050243442);
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R11[Dtype(RTCW(arg3))-3])(arg3, tr1);
	if (tb1) {
		RTHOOK(3);
		tr1 = RTLNSMART(eif_new_type(29, 0).id);
		F30_1286(RTCW(tr1));
		RTAR(Current, tr1);
		*(EIF_REFERENCE *)(Current + _REFACS_2_) = (EIF_REFERENCE) tr1;
		RTHOOK(4);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_5_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		RTHOOK(5);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
		loc1 = F7245_105173(RTCW(tr1));
		
		RTHOOK(7);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_0_0_2_);
		ti4_2 = *(EIF_INTEGER_32 *)(RTCW(loc1)+ _LNGOFF_1_0_0_1_);
		F30_1291(RTCW(tr1), (EIF_INTEGER_32) ((EIF_INTEGER_32) (*(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_1_0_0_) + ti4_1) - ti4_2));
	}
	RTHOOK(8);
	F1052_16184(Current, arg1, arg2, arg3);
	RTHOOK(9);
	RTLE;
	RTEE;
}

/* {MEMBER_FILTER}.on_attribute */
void F1056_16231 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	RTLD;
	
	RTLI(9);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLR(3,loc2);
	RTLR(4,arg4);
	RTLR(5,loc1);
	RTLR(6,arg1);
	RTLR(7,arg2);
	RTLR(8,arg3);
	RTLIU(9);
	
	RTEAA("on_attribute", 1055, Current, 2, 4, 14125);
	RTGC;
	RTHOOK(1);
	tb1 = '\0';
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_5_0_)) {
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
		tr1 = F2640_30073(RTCW(tr1));
		tr2 = RTMS_EX_H("member",6,2050243442);
		tb2 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R11[Dtype(RTCW(tr1))-3])(tr1, tr2);
		tb1 = tb2;
	}
	if (tb1) {
		
		RTHOOK(3);
		loc2 = arg4;
		loc2 = RTRV(eif_new_type(4148, 0x00), loc2);
		RTHOOK(4);
		if ((EIF_BOOLEAN)(loc2 != NULL)) {
			RTHOOK(5);
			loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R40923[Dtype(RTCW(loc2))-4147])(loc2);
		} else {
			RTHOOK(6);
			loc1 = (EIF_REFERENCE) eif_builtin_ANY_twin (arg4);
		}
		RTHOOK(7);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc1) + O40942[Dtype(loc1)-4146]);
		(FUNCTION_CAST(void, (EIF_REFERENCE, EIF_INTEGER_32)) R40797[Dtype(RTCW(loc1))-4143])(loc1, (EIF_INTEGER_32) (ti4_1 - ((EIF_INTEGER_32) 2L)));
		RTHOOK(8);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		F30_1290(RTCW(tr1), loc1);
		RTHOOK(9);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_5_0_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	}
	RTHOOK(10);
	F1052_16185(Current, arg1, arg2, arg3, arg4);
	RTHOOK(11);
	RTLE;
	RTEE;
}

/* {MEMBER_FILTER}.on_end_tag */
void F1056_16232 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3)
{
	GTCX
	RTEX;
	EIF_INTEGER_32 loc1 = (EIF_INTEGER_32) 0;
	EIF_REFERENCE loc2 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	RTLD;
	
	RTLI(7);
	RTLR(0,arg3);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,loc2);
	RTLR(4,tr2);
	RTLR(5,arg1);
	RTLR(6,arg2);
	RTLIU(7);
	
	RTEAA("on_end_tag", 1055, Current, 2, 3, 14126);
	RTGC;
	RTHOOK(1);
	tr1 = RTMS_EX_H("member",6,2050243442);
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE, EIF_REFERENCE)) R11[Dtype(RTCW(arg3))-3])(arg3, tr1);
	if (tb1) {
		RTHOOK(2);
		tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
		ti4_1 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_0_0_0_);
		if ((EIF_BOOLEAN) (ti4_1 > ((EIF_INTEGER_32) 0L))) {
			RTHOOK(3);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_4_);
			loc2 = F7245_105173(RTCW(tr1));
			
			RTHOOK(5);
			loc1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_5_1_0_0_);
			ti4_1 = *(EIF_INTEGER_32 *)(RTCW(loc2)+ _LNGOFF_1_0_0_2_);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
			ti4_2 = *(EIF_INTEGER_32 *)(RTCW(tr1)+ _LNGOFF_1_0_0_0_);
			loc1 = (EIF_INTEGER_32) (EIF_INTEGER_32) ((EIF_INTEGER_32) (loc1 + ti4_1) - ti4_2);
			RTHOOK(6);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
			F30_1292(RTCW(tr1), loc1);
			RTHOOK(7);
			tr1 = *(EIF_REFERENCE *)(Current + _REFACS_1_);
			tr2 = *(EIF_REFERENCE *)(Current + _REFACS_2_);
			tr2 = *(EIF_REFERENCE *)(RTCW(tr2));
			F2723_30566(RTCW(tr1), *(EIF_REFERENCE *)(Current + _REFACS_2_), tr2);
		}
	}
	RTHOOK(8);
	tr1 = *(EIF_REFERENCE *)(Current + _REFACS_3_);
	F2670_30251(RTCW(tr1));
	RTHOOK(9);
	F1052_16187(Current, arg1, arg2, arg3);
	RTHOOK(10);
	RTLE;
	RTEE;
}

/* {MEMBER_FILTER}.set_parser */
void F1056_16234 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	RTEX;
	
	
	RTEAA("set_parser", 1055, Current, 0, 1, 14128);
	RTHOOK(1);
	RTAR(Current, arg1);
	*(EIF_REFERENCE *)(Current + _REFACS_4_) = (EIF_REFERENCE) arg1;
	RTHOOK(3);
	RTEE;
}

void EIF_Minit951 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
